@@ -387,8 +387,8 @@ class EntitySchema(PermissionMixIn, ERSchema):
             if rdef.object == 'Boolean':
                 if not isinstance(default, bool):
                     default = default == 'True' # XXX duh?
-            elif rdef.object == 'Int':
-                if not isinstance(default, int):
+            elif rdef.object in ('Int', 'BigInt'):
+                if not isinstance(default, (int, long)):
                     default = int(default)
             elif rdef.object == 'Float':
                 if not isinstance(default, float):
@@ -1199,7 +1199,7 @@ class Schema(object):
 
     def infer_specialization_rules(self):
         for rschema in self.relations():
-            if rschema.final or rschema in self.no_specialization_inference:
+            if rschema in self.no_specialization_inference:
                 continue
             for (subject, object), rdef in rschema.rdefs.items():
                 subjeschemas = [subject] + subject.specialized_by(recursive=True)
