@@ -1,5 +1,22 @@
-from yams.buildobjs import EntityType, RelationType, SubjectRelation, \
-     ObjectRelation, Int, String,  Boolean
+# copyright 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of yams.
+#
+# yams is free software: you can redistribute it and/or modify it under the
+# terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option)
+# any later version.
+#
+# yams is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with yams. If not, see <http://www.gnu.org/licenses/>.
+from yams.buildobjs import (EntityType, RelationType, RelationDefinition,
+                            SubjectRelation, Int, String,  Boolean)
 from yams.constraints import SizeConstraint, UniqueConstraint
 
 from data.schema import RESTRICTED_RTYPE_PERMS
@@ -24,7 +41,6 @@ class State(EntityType):
     # relations
     state_of = SubjectRelation('Eetype', cardinality='+*')
     next_state = SubjectRelation('State', cardinality='**')
-    initial_state = ObjectRelation('Eetype', cardinality='?*')
 
 
 class state_of(RelationType):
@@ -45,6 +61,9 @@ class initial_state(RelationType):
         'add':    ('managers', 'users',),
         'delete': ('managers', 'users',),
         }
+    subject = 'Eetype'
+    object = 'State'
+    cardinality = '?*'
     inlined = True
 
 class Eetype(EntityType):
